# ------------------------------------------------------------------
# Copyright (c) 2020 PyInstaller Development Team.
#
# This file is distributed under the terms of the GNU General Public
# License (version 2.0 or later).
#
# The full license is available in LICENSE.GPL.txt, distributed with
# this software.
#
# SPDX-License-Identifier: GPL-2.0-or-later
# ------------------------------------------------------------------
#
# Hook for the phonenumbers package: https://pypi.org/project/phonenumbers/
#
# Tested with phonenumbers 8.9.7 and Python 3.6.1, on Ubuntu 16.04 64bit.

from PyInstaller.utils.hooks import collect_submodules

hiddenimports = collect_submodules('phonenumbers')
